export interface FunctionSignature {
    fullText: string;
    name: string;
    parameters: Array<{
        fullText: string;
        name: string;
        optional?: boolean;
        defaultValue?: string;
    }>;
}
export interface FunctionItem {
    /** 文档的公网链接 */
    href: string;
    /** 部分函数存在多个签名，例如 append! 和 x.append!, eachPre 和 func:P 这两组，最好在分析阶段就处理好 */
    signatures: FunctionSignature[] | null;
    /** 文档内容 */
    markdown: string;
}
type Docs = Record<string, FunctionItem>;
export declare class DocsAnalyser {
    /** 文档原始信息 */
    docs?: Docs;
    /** 函数名列表 */
    funcs: string[];
    /** 转化成小写字母的函数名列表 */
    lowerFuncs: string[];
    updateDocs(docs: Docs): void;
    loadDocsAsync(provider: string | (() => Promise<Docs>)): Promise<void>;
    getFunctionMarkdown(name: string): string | undefined;
    getSignatures(name: string): FunctionSignature[] | null | undefined;
    /**
     * 查询补全项（包括关键字、常量和函数）
     * @param query
     * @returns
     */
    searchCompletionItems(query: string): {
        keywords: string[];
        constants: ("NULL" | "true" | "false" | "pi" | "e" | "SCALAR" | "VECTOR" | "PAIR" | "MATRIX" | "SET" | "DICT" | "TABLE" | "VOID" | "BOOL" | "CHAR" | "SHORT" | "INT" | "INDEX" | "LONG" | "DATE" | "MONTH" | "TIME" | "MINUTE" | "SECOND" | "DATETIME" | "TIMESTAMP" | "NANOTIME" | "NANOTIMESTAMP" | "FLOAT" | "DOUBLE" | "SYMBOL" | "STRING" | "UUID" | "FUNCTIONDEF" | "HANDLE" | "CODE" | "DATASOURCE" | "RESOURCE" | "ANY" | "DICTIONARY" | "DATEHOUR" | "IPADDR" | "INT128" | "BLOB" | "COMPLEX" | "POINT" | "DURATION" | "OBJECT" | "DECIMAL32" | "DECIMAL64" | "DECIMAL128" | "SEQ" | "RANGE" | "HASH" | "VALUE" | "LIST" | "COMPO" | "VAR" | "SHARED" | "DEF" | "GLOBAL" | "TABLE_READ" | "TABLE_WRITE" | "TABLE_INSERT" | "TABLE_UPDATE" | "TABLE_DELETE" | "DBOBJ_CREATE" | "DBOBJ_DELETE" | "DB_DELETE" | "DB_INSERT" | "DB_MANAGE" | "DB_OWNER" | "DB_READ" | "DB_UPDATE" | "DB_WRITE" | "SCRIPT_EXEC" | "TASK_GROUP_MEM_LIMIT" | "TEST_EXEC" | "VIEW_EXEC" | "QUERY_RESULT_MEM_LIMIT" | "HINT_HASH" | "HINT_SNAPSHOT" | "HINT_KEEPORDER" | "HINT_SEQ" | "HINT_EXPLAIN" | "HINT_VECTORIZED" | "HEAD" | "CURRENT" | "TAIL" | "LINE" | "PIE" | "COLUMN" | "BAR" | "AREA" | "SCATTER" | "HISTOGRAM" | "KLINE" | "DEBUG" | "INFO" | "WARNING" | "ERROR" | "FIRST" | "LAST" | "ALL" | "NONE" | "HASH_PTN" | "True" | "False" | "None")[];
        functions: string[];
    };
}
export {};
