import { keywords, constants } from 'dolphindb/language.js';
function isCompletionMatch(target, search) {
    let j = 0;
    for (const c of search) {
        j = target.indexOf(c, j) + 1;
        if (!j) {
            // 找不到则 j === 0
            return false;
        }
    }
    return true;
}
export class DocsAnalyser {
    /** 文档原始信息 */
    docs;
    /** 函数名列表 */
    funcs = [];
    /** 转化成小写字母的函数名列表 */
    lowerFuncs = [];
    updateDocs(docs) {
        this.docs = docs;
        this.funcs = Object.keys(docs);
        this.lowerFuncs = this.funcs.map((func) => func.toLowerCase());
    }
    async loadDocsAsync(provider) {
        let docs;
        if (typeof provider === 'function') {
            docs = await provider();
        }
        else if (typeof provider === 'string') {
            docs = await (await fetch(provider)).json();
        }
        else {
            throw new Error('Invalid docs provider');
        }
        this.updateDocs(docs);
    }
    getFunctionMarkdown(name) {
        return this.docs?.[name]?.markdown;
    }
    getSignatures(name) {
        return this.docs?.[name]?.signatures;
    }
    /**
     * 查询补全项（包括关键字、常量和函数）
     * @param query
     * @returns
     */
    searchCompletionItems(query) {
        const queryLower = query.toLowerCase();
        return {
            keywords: keywords.filter((keyword) => keyword.startsWith(query)),
            constants: constants.filter((constant) => isCompletionMatch(constant, queryLower)),
            functions: this.funcs.filter((func, i) => isCompletionMatch(this.lowerFuncs[i], queryLower)),
        };
    }
}
//# sourceMappingURL=analyser.js.map